@@ -407,6 +407,8 @@
 \\majorSevenSymbol
 \\major
 \\maininput
+\\magnifyStaff
+\\magnifyMusic
 \\magnify
 \\lyricsto
 \\lyrics
